@@ -1,4 +1,4 @@
-from silo import Silo, RDFSilo
+from silo import Silo, RDFSilo, Granary
 from records import HarvestedRecord, RDFRecord
 from persiststate import PersistentState
 from rdfmanifest import RDFManifest
