@@ -42,6 +42,7 @@ class HarvestedRecord(object):
     def __init__(self, pairtree_object, date=None, manifest_filename="__manifest.json"):
         self.po = pairtree_object
         self.item_id = self.po.id
+        self.uri = self.po.uri
         self.manifest_filename = manifest_filename
         if not date:
             date = datetime.now().isoformat()
@@ -150,20 +151,18 @@ class HarvestedRecord(object):
 
     def _copy_version(self, latest_version, new_version, exclude_filenames=[]):
         version_state = self.manifest['currentversion']
-        self.set_version_cursor(new_version)
+        self.set_version_cursor(latest_version)
+        self._reload_filelist(new_version)
         for x in [y for y in self.manifest['files'][latest_version] if y not in exclude_filenames]:
             self._copy_file(x, latest_version, new_version, sync=False)
         self.set_version_cursor(version_state)
-        self.sync()
     
     def _copy_file(self, filename, latest_version, new_version, sync = True):
-        with self.get_stream(filename, version=latest_version) as stream:
+        with self.get_stream(filename, version=latest_version) as filetostream:
             metadata = False
             if filename in self.manifest['metadata_files'][latest_version]:
                 metadata = True
-            self.put_stream(filename, stream, metadata=metadata)
-        if sync:
-            self.sync()
+            self.put_stream(filename, filetostream, version=new_version, metadata=metadata, sync=sync)
 
     def path_to_item(self):
         return self.po.fs._id_to_dirpath(self.po.id)
@@ -210,15 +209,17 @@ class HarvestedRecord(object):
         self.manifest.revert()
         self._init_manifests_emptydatastructures()
     
-    def put_stream(self, filename, stream, metadata=False):
-        version = self.manifest['currentversion']
+    def put_stream(self, filename, filetostream, version=None, metadata=False, sync=True):
+        if not version:
+            version = self.manifest['currentversion']
         if metadata and filename not in self.manifest['metadata_files'][version]:
             self.manifest['metadata_files'][version].append(filename)
         if filename not in self.manifest['files'][version]:
             self.manifest['files'][version].append(filename)
-        resp = self.po.add_bytestream_by_path(path.join("__" + str(version), filename), stream)
+        resp = self.po.add_bytestream_by_path(path.join("__" + str(version), filename), filetostream)
         self._reload_filelist(version)
-        self.sync()
+        if sync:
+            self.sync()
         return resp
     def get_stream(self, filename, version=None, writeable=False):
         """NB If writeable is set to True, then the file is opened "wb+" and can accept writes.
@@ -288,9 +289,9 @@ class HarvestedRecord(object):
         if original_version in self.manifest['versions']:
             date = self.manifest['version_dates'][original_version]
             self._setup_version_dir(new_version, date)
-            self.set_version_cursor(new_version)
             self._read_date()
             self._copy_version(original_version, new_version, exclude_filenames)
+            self.set_version_cursor(new_version)
             self.sync()
             return new_version
         else:
@@ -386,13 +387,30 @@ class RDFRecord(HarvestedRecord):
     def load_rdf_manifest(self, version=None):
         format = self.manifest.get('rdffileformat', 'xml')
         fpath = self._path_to_rdfmanifest()
-        self.rdfmanifest = RDFManifest(fpath, format=format, uri=self.po.uri)
+        if self.manifest.has_key('rdffilename') and self.manifest['rdffilename'] not in self.manifest['files'][self.manifest['currentversion']]:
+            self.manifest['files'][self.manifest['currentversion']].append(self.manifest['rdffilename'])
+        self._rdfmanifest = RDFManifest(fpath, format=format, uri=self.po.uri)
     
     def get_rdf_manifest(self):
-        if not self.rdfmanifest:
+        if not self._rdfmanifest:
             self.load_rdf_manifest()
-        return self.rdfmanifest
+        return self._rdfmanifest
 
+    def add_triple(self, s, p, o):
+        return self._rdfmanifest.add_triple(s,p,o)
+    def add_namespace(self, prefix, uri):
+        return self._rdfmanifest.add_namespace(prefix, uri)
+    def del_triple(self, s, p, o=None):
+        return self._rdfmanifest.del_triple(s,p,o)
+    def del_namespace(self, prefix):
+        return self._rdfmanifest.del_namespace(prefix)
+    def get_graph(self):
+        return self._rdfmanifest.get_graph()
+    def get_graph(self):
+        return self._rdfmanifest.get_graph()
+    def rdf_to_string(self, format="xml"):
+        return self._rdfmanifest.to_string(format)
+    
     ##############
     ## Classes to annotate with rdf manifest updating
     
@@ -402,10 +420,17 @@ class RDFRecord(HarvestedRecord):
         
     def revert(self, **kw):
         super(RDFRecord, self).revert(**kw)
+        if self.manifest.has_key('rdffilename') and self.manifest['rdffilename'] not in self.manifest['files'][self.manifest['currentversion']]:
+            self.manifest['files'][self.manifest['currentversion']].append(self.manifest['rdffilename'])
         self.load_rdf_manifest()
         
     def sync(self):
         super(RDFRecord, self).sync()
-        if self.rdfmanifest:
-            self.rdfmanifest.sync()
-    
+        if self.manifest.has_key('rdffilename') and self.manifest['rdffilename'] not in self.manifest['files'][self.manifest['currentversion']]:
+            self.manifest['files'][self.manifest['currentversion']].append(self.manifest['rdffilename'])
+        if self._rdfmanifest: 
+            self._rdfmanifest.sync()
+
+    def _copy_version(self, latest_version, new_version, exclude_filenames=[]):
+        super(RDFRecord, self)._copy_version(latest_version, new_version, exclude_filenames)
+        self.load_rdf_manifest()
