@@ -12,7 +12,7 @@ from pairtree import FileNotFoundException, ObjectNotFoundException
 
 from datetime import datetime
 
-from os import path, mkdir, rename
+from os import path, mkdir, rename, listdir
 
 from shutil import copy2
 
@@ -128,3 +128,21 @@ class RDFSilo(Silo):
         else:
             raise ObjectNotFoundException
 
+class Granary(object):
+    def __init__(self, dir_of_silos="data"):
+        self.root_dir = dir_of_silos
+        self._init_granary()
+    
+    def _init_granary(self):
+        if not path.exists(self.root_dir):
+            mkdir(self.root_dir)
+        self.silos = [x for x in listdir(self.root_dir) if self.issilo(x)]
+        
+    def issilo(self, silo_name):
+        return path.isdir(path.join(self.root_dir, silo_name)) and path.exists(path.join(self.root_dir, silo_name, 'pairtree_root'))
+    
+    def get_silo(self, silo_name, uri_base=None, **kw):
+        return Silo(path.join(self.root_dir, silo_name), uri_base=uri_base, **kw)
+        
+    def get_rdf_silo(self, silo_name, uri_base=None, **kw):
+        return RDFSilo(path.join(self.root_dir, silo_name), uri_base=uri_base, **kw)
